"""
Django Server Tag Package

A Django package to fetch and render scripts from a remote URL with template tag integration.
"""

__version__ = '1.0.0'
__author__ = 'Adunblock'

default_app_config = 'server_tag.apps.ServerTagConfig'



import requests
from django import template
from django.core.cache import cache
from django.utils.safestring import mark_safe

register = template.Library()

@register.simple_tag
def server_tag(remote_url, cache_interval=300, render_script=None):
    cached_data = cache.get(remote_url)

    if cached_data:
        js_files = cached_data
    else:
        try:
            response = requests.get(remote_url)
            response.raise_for_status()
            data = response.json()
            # New format: API returns array directly instead of object with js property
            if isinstance(data, list):
                # New format: array directly
                js_files = {'js': data}
            elif isinstance(data, dict) and 'js' in data:
                # Old format: object with js property (backward compatibility)
                js_files = data
            else:
                js_files = {'js': []}
            cache.set(remote_url, js_files, cache_interval)
        except requests.exceptions.RequestException as e:
            print(f'Error fetching remote script: {e}')
            js_files = {'js': []}

    if render_script:
        return mark_safe(render_script(js_files))
    else:
        from django.utils.html import escape
        scripts = [f'<script src="{escape(src)}" async></script>' for src in js_files.get('js', [])]
        return mark_safe('\n'.join(scripts))




from setuptools import setup, find_packages

setup(
    name='adunblock-server-tag-django',
    version='1.0.0',
    packages=find_packages(),
    include_package_data=True,
    license='ISC',
    description='A Django package to fetch and render scripts from a remote URL.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    install_requires=[
        'Django',
        'requests',
    ],
)
